@@ -1,7 +1,6 @@
 #include "random.h"
 
 /* static functions.. */
-static int ncomp_optimal(double);
 static DIMS dims(int *);
 static void dims_free(DIMS);
 /* ..end declarations */
@@ -63,7 +62,7 @@ rand_norm(double *y, int *pdims, double *center, double *Scatter)
     char *side = "L", *uplo = "U", *trans = "T", *diag = "N";
     double one = 1.;
     int i, inc = 1, info = 0, job = 1;
-    
+
     dm = dims(pdims);
     GetRNGstate();
     chol_decomp(Scatter, dm->p, dm->p, job, &info);
@@ -101,7 +100,7 @@ rand_cauchy(double *y, int *pdims, double *center, double *Scatter)
     char *side = "L", *uplo = "U", *trans = "T", *diag = "N";
     double one = 1.;
     int i, inc = 1, info = 0, job = 1;
-    
+
     dm = dims(pdims);
     GetRNGstate();
     chol_decomp(Scatter, dm->p, dm->p, job, &info);
@@ -143,7 +142,7 @@ rand_student(double *y, int *pdims, double *center, double *Scatter, double *df)
     char *side = "L", *uplo = "U", *trans = "T", *diag = "N";
     double one = 1.;
     int i, inc = 1, info = 0, job = 1;
-    
+
     dm = dims(pdims);
     GetRNGstate();
     chol_decomp(Scatter, dm->p, dm->p, job, &info);
@@ -185,7 +184,7 @@ rand_slash(double *y, int *pdims, double *center, double *Scatter, double *df)
     char *side = "L", *uplo = "U", *trans = "T", *diag = "N";
     double one = 1.;
     int i, inc = 1, info = 0, job = 1;
-    
+
     dm = dims(pdims);
     GetRNGstate();
     chol_decomp(Scatter, dm->p, dm->p, job, &info);
@@ -228,7 +227,7 @@ rand_contaminated(double *y, int *pdims, double *center, double *Scatter,
     char *side = "L", *uplo = "U", *trans = "T", *diag = "N";
     double one = 1.;
     int i, inc = 1, info = 0, job = 1;
-    
+
     dm = dims(pdims);
     GetRNGstate();
     chol_decomp(Scatter, dm->p, dm->p, job, &info);
@@ -261,67 +260,3 @@ rand_spherical_contaminated(double *y, double eps, double vif, int n, int p)
         y += p;
     }
 }
-
-/* random number generation of right truncated Gamma distribution using mixtures. 
- * Original C code from Anne Philippe (1997).
- */
-
-static int
-ncomp_optimal(double b)
-{   /* optimal number of components for p = 0.95 fixed */
-    double ans, q = 1.644853626951;
-    ans = 0.25 * R_pow_di(q * sqrt(q * q + 4. * b), 2);
-    return ((int) ftrunc(ans));
-}
-
-double
-rtgamma_right_standard(double a, double b)
-{   /* random number generation from the gamma with right truncation point t = 1, i.e. TG^-(a,b,1) */
-    int n, i, j;
-    double x, u, y, z, yy, zz;
-    double *wl, *wlc;
-
-    n = ncomp_optimal(b);
-    wl  = (double *) Calloc(n + 2, double);
-    wlc = (double *) Calloc(n + 2, double);
-
-    wl[0] = 1.0; wlc[0] = 1.0;
-    for (i = 1; i <= n; i++) {
-        wl[i]  = wl[i-1] * b / (a + i);
-        wlc[i] = wlc[i-1] + wl[i];
-    }
-    for (i = 0; i <= n; i++)
-        wlc[i] = wlc[i] / wlc[n];
-    y = 1.0; yy = 1.0;
-    for (i = 1; i <= n; i++) {
-        yy *= b / i;
-        y  += yy;
-    }
-
-    repeat {
-        u = unif_rand();
-        j = 0;
-        while (u > wlc[j])
-            j += 1;
-        x = rbeta(a, (double) j + 1);
-        u = unif_rand();
-        z = 1.0; zz = 1.0;
-        for (i = 1; i <= n; i++) {
-            zz *= (1 - x) * b / i;
-            z  += zz;
-        }
-        z = exp(-b * x) * y / z;
-        if (u <= z)
-            break;
-    }
-    Free(wl); Free(wlc);
-    return x;
-}
-
-double
-rtgamma_right(double shape, double rate, double truncation)
-{   /* random number generation from the gamma with right truncation point, i.e. TG^-(a,b,t) */
-    double x;
-    x = rtgamma_right_standard(shape, rate * truncation) * truncation;
-    return x;
-}
